@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Adrian Sampson.
 #
@@ -15,12 +14,10 @@
 
 """Searches for albums in the MusicBrainz database.
 """
-from __future__ import division, absolute_import, print_function
 
 import musicbrainzngs
 import re
 import traceback
-from six.moves.urllib.parse import urljoin
 
 from beets import logging
 from beets import plugins
@@ -28,14 +25,12 @@ import beets.autotag.hooks
 import beets
 from beets import util
 from beets import config
-import six
+from collections import Counter
+from urllib.parse import urljoin
 
 VARIOUS_ARTISTS_ID = '89ad4ac3-39f7-470e-963a-56509c546377'
 
-if util.SNI_SUPPORTED:
-    BASE_URL = 'https://musicbrainz.org/'
-else:
-    BASE_URL = 'http://musicbrainz.org/'
+BASE_URL = 'https://musicbrainz.org/'
 
 SKIPPED_TRACKS = ['[data track]']
 
@@ -55,17 +50,19 @@ class MusicBrainzAPIError(util.HumanReadableException):
     """An error while talking to MusicBrainz. The `query` field is the
     parameter to the action and may have any type.
     """
+
     def __init__(self, reason, verb, query, tb=None):
         self.query = query
         if isinstance(reason, musicbrainzngs.WebServiceError):
-            reason = u'MusicBrainz not reachable'
-        super(MusicBrainzAPIError, self).__init__(reason, verb, tb)
+            reason = 'MusicBrainz not reachable'
+        super().__init__(reason, verb, tb)
 
     def get_message(self):
-        return u'{0} in {1} with query {2}'.format(
+        return '{} in {} with query {}'.format(
             self._reasonstr(), self.verb, repr(self.query)
         )
 
+
 log = logging.getLogger('beets')
 
 RELEASE_INCLUDES = ['artists', 'media', 'recordings', 'release-groups',
@@ -159,7 +156,7 @@ def _flatten_artist_credit(credit):
     artist_sort_parts = []
     artist_credit_parts = []
     for el in credit:
-        if isinstance(el, six.string_types):
+        if isinstance(el, str):
             # Join phrase.
             artist_parts.append(el)
             artist_credit_parts.append(el)
@@ -212,7 +209,7 @@ def track_info(recording, index=None, medium=None, medium_index=None,
         medium=medium,
         medium_index=medium_index,
         medium_total=medium_total,
-        data_source=u'MusicBrainz',
+        data_source='MusicBrainz',
         data_url=track_url(recording['id']),
     )
 
@@ -255,10 +252,10 @@ def track_info(recording, index=None, medium=None, medium_index=None,
                     composer_sort.append(
                         artist_relation['artist']['sort-name'])
     if lyricist:
-        info.lyricist = u', '.join(lyricist)
+        info.lyricist = ', '.join(lyricist)
     if composer:
-        info.composer = u', '.join(composer)
-        info.composer_sort = u', '.join(composer_sort)
+        info.composer = ', '.join(composer)
+        info.composer_sort = ', '.join(composer_sort)
 
     arranger = []
     for artist_relation in recording.get('artist-relation-list', ()):
@@ -267,7 +264,7 @@ def track_info(recording, index=None, medium=None, medium_index=None,
             if type == 'arranger':
                 arranger.append(artist_relation['artist']['name'])
     if arranger:
-        info.arranger = u', '.join(arranger)
+        info.arranger = ', '.join(arranger)
 
     # Supplementary fields provided by plugins
     extra_trackdatas = plugins.send('mb_track_extract', data=recording)
@@ -312,14 +309,14 @@ def album_info(release):
     # when the release has more than 500 tracks. So we use browse_recordings
     # on chunks of tracks to recover the same information in this case.
     if ntracks > BROWSE_MAXTRACKS:
-        log.debug(u'Album {} has too many tracks', release['id'])
+        log.debug('Album {} has too many tracks', release['id'])
         recording_list = []
         for i in range(0, ntracks, BROWSE_CHUNKSIZE):
-            log.debug(u'Retrieving tracks starting at {}', i)
+            log.debug('Retrieving tracks starting at {}', i)
             recording_list.extend(musicbrainzngs.browse_recordings(
-                    release=release['id'], limit=BROWSE_CHUNKSIZE,
-                    includes=BROWSE_INCLUDES,
-                    offset=i)['recording-list'])
+                release=release['id'], limit=BROWSE_CHUNKSIZE,
+                includes=BROWSE_INCLUDES,
+                offset=i)['recording-list'])
         track_map = {r['id']: r for r in recording_list}
         for medium in release['medium-list']:
             for recording in medium['track-list']:
@@ -392,7 +389,7 @@ def album_info(release):
         mediums=len(release['medium-list']),
         artist_sort=artist_sort_name,
         artist_credit=artist_credit_name,
-        data_source=u'MusicBrainz',
+        data_source='MusicBrainz',
         data_url=album_url(release['id']),
     )
     info.va = info.artist_id == VARIOUS_ARTISTS_ID
@@ -416,18 +413,17 @@ def album_info(release):
         if reltype:
             info.albumtype = reltype.lower()
 
-    # Log the new-style "primary" and "secondary" release types.
-    # Eventually, we'd like to actually store this data, but we just log
-    # it for now to help understand the differences.
+    # Set the new-style "primary" and "secondary" release types.
+    albumtypes = []
     if 'primary-type' in release['release-group']:
         rel_primarytype = release['release-group']['primary-type']
         if rel_primarytype:
-            log.debug('primary MB release type: ' + rel_primarytype.lower())
+            albumtypes.append(rel_primarytype.lower())
     if 'secondary-type-list' in release['release-group']:
         if release['release-group']['secondary-type-list']:
-            log.debug('secondary MB release type(s): ' + ', '.join(
-                [secondarytype.lower() for secondarytype in
-                    release['release-group']['secondary-type-list']]))
+            for sec_type in release['release-group']['secondary-type-list']:
+                albumtypes.append(sec_type.lower())
+    info.albumtypes = '; '.join(albumtypes)
 
     # Release events.
     info.country, release_date = _preferred_release_event(release)
@@ -458,9 +454,17 @@ def album_info(release):
         first_medium = release['medium-list'][0]
         info.media = first_medium.get('format')
 
-    genres = release.get('genre-list')
-    if config['musicbrainz']['genres'] and genres:
-        info.genre = ';'.join(g['name'] for g in genres)
+    if config['musicbrainz']['genres']:
+        sources = [
+            release['release-group'].get('genre-list', []),
+            release.get('genre-list', []),
+        ]
+        genres = Counter()
+        for source in sources:
+            for genreitem in source:
+                genres[genreitem['name']] += int(genreitem['count'])
+        info.genre = '; '.join(g[0] for g in sorted(genres.items(),
+                                                    key=lambda g: -g[1]))
 
     extra_albumdatas = plugins.send('mb_album_extract', data=release)
     for extra_albumdata in extra_albumdatas:
@@ -486,15 +490,15 @@ def match_album(artist, album, tracks=None, extra_tags=None):
         # Various Artists search.
         criteria['arid'] = VARIOUS_ARTISTS_ID
     if tracks is not None:
-        criteria['tracks'] = six.text_type(tracks)
+        criteria['tracks'] = str(tracks)
 
     # Additional search cues from existing metadata.
     if extra_tags:
         for tag in extra_tags:
             key = FIELDS_TO_MB_KEYS[tag]
-            value = six.text_type(extra_tags.get(tag, '')).lower().strip()
+            value = str(extra_tags.get(tag, '')).lower().strip()
             if key == 'catno':
-                value = value.replace(u' ', '')
+                value = value.replace(' ', '')
             if value:
                 criteria[key] = value
 
@@ -503,7 +507,7 @@ def match_album(artist, album, tracks=None, extra_tags=None):
         return
 
     try:
-        log.debug(u'Searching for MusicBrainz releases with: {!r}', criteria)
+        log.debug('Searching for MusicBrainz releases with: {!r}', criteria)
         res = musicbrainzngs.search_releases(
             limit=config['musicbrainz']['searchlimit'].get(int), **criteria)
     except musicbrainzngs.MusicBrainzError as exc:
@@ -544,7 +548,7 @@ def _parse_id(s):
     no ID can be found, return None.
     """
     # Find the first thing that looks like a UUID/MBID.
-    match = re.search(u'[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}', s)
+    match = re.search('[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}', s)
     if match:
         return match.group()
 
@@ -554,19 +558,19 @@ def album_for_id(releaseid):
     object or None if the album is not found. May raise a
     MusicBrainzAPIError.
     """
-    log.debug(u'Requesting MusicBrainz release {}', releaseid)
+    log.debug('Requesting MusicBrainz release {}', releaseid)
     albumid = _parse_id(releaseid)
     if not albumid:
-        log.debug(u'Invalid MBID ({0}).', releaseid)
+        log.debug('Invalid MBID ({0}).', releaseid)
         return
     try:
         res = musicbrainzngs.get_release_by_id(albumid,
                                                RELEASE_INCLUDES)
     except musicbrainzngs.ResponseError:
-        log.debug(u'Album ID match failed.')
+        log.debug('Album ID match failed.')
         return None
     except musicbrainzngs.MusicBrainzError as exc:
-        raise MusicBrainzAPIError(exc, u'get release by ID', albumid,
+        raise MusicBrainzAPIError(exc, 'get release by ID', albumid,
                                   traceback.format_exc())
     return album_info(res['release'])
 
@@ -577,14 +581,14 @@ def track_for_id(releaseid):
     """
     trackid = _parse_id(releaseid)
     if not trackid:
-        log.debug(u'Invalid MBID ({0}).', releaseid)
+        log.debug('Invalid MBID ({0}).', releaseid)
         return
     try:
         res = musicbrainzngs.get_recording_by_id(trackid, TRACK_INCLUDES)
     except musicbrainzngs.ResponseError:
-        log.debug(u'Track ID match failed.')
+        log.debug('Track ID match failed.')
         return None
     except musicbrainzngs.MusicBrainzError as exc:
-        raise MusicBrainzAPIError(exc, u'get recording by ID', trackid,
+        raise MusicBrainzAPIError(exc, 'get recording by ID', trackid,
                                   traceback.format_exc())
     return track_info(res['recording'])
